package com.hornettest.client;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectOutputStream;

import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.MessageProducer;
import javax.jms.ObjectMessage;
import javax.jms.Queue;
import javax.jms.Session;
import javax.naming.InitialContext;

import org.apache.commons.httpclient.methods.GetMethod;

import com.hornettest.ejb.ProducerEJB;
import com.hornettest.ejb.TestEJB;
import com.hornettest.entity.SentMessage;
import com.hornettest.util.HornetTestUtils;

public class FastProducerClient {

	/**
	 * @param args
	 * @throws Exception 
	 */
	public static void main(String[] args) throws Exception {
		Connection connection = null;
		InitialContext initialContext = null;
		try {
			// Step 1. Create an initial context to perform the JNDI lookup.
			initialContext = HornetTestUtils.getHornetQInitialContext();

			// Step 2. Perfom a lookup on the queue
			Queue queue = (Queue) initialContext
					.lookup("/queue/slowConsumerQueue");

			// Step 3. Perform a lookup on the Connection Factory
			ConnectionFactory cf = (ConnectionFactory) initialContext
					.lookup("/XAConnectionFactory");

			// Step 4. Create a JMS Connection
			connection = cf.createConnection();

			// Step 5. Create a JMS Session
			Session session = connection.createSession(false,
					Session.AUTO_ACKNOWLEDGE);

			// Step 6. Create a JMS Message Producer
			MessageProducer producer = session.createProducer(queue);

			for (int i = 0; i < 10000; i++) {
				long time = System.currentTimeMillis();
				SentMessage st = new SentMessage();
				st.setId(i);
				st.setValue("MSG" + time);
				ObjectMessage msg = session.createObjectMessage(st);
				System.out.println(msg.getJMSDeliveryMode());
				System.out.println("sending msg " + st.getId());
				try {
					producer.send(msg);
				} catch(Exception e){
					e.printStackTrace();
				}
			}
//
//			initialContext = HornetTestUtils.getJbossInitialContext();
//			ProducerEJB[] producerArray = new ProducerEJB[520];
//			for(int i=0 ; i<50; i++){
//				ProducerEJB remoteProducerEJb = (ProducerEJB) initialContext.lookup("ProducerEJBImpl/remote");
//				System.out.println("producer instance  "  + i +": "+ remoteProducerEJb) ;
//				producerArray[i] = remoteProducerEJb;
//			}
//			for (int i = 0; i < 10000; i=i+50) {
//				for(int j=0; j<50; j++) {
//					long time = System.currentTimeMillis();
//					try {
//						producerArray[j].testHugeMessages(i++, "MSG"+time);
//					} catch(Exception e){e.printStackTrace();}
//				}
//			}
			
		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		}

	}
	
	static private int getMessageSizeInBytes(SentMessage message) throws IOException {
	    ByteArrayOutputStream baos = new ByteArrayOutputStream();
	    ObjectOutputStream oos = new ObjectOutputStream(baos);
	    oos.writeObject(message);
	    oos.close();
	    return baos.size();
	}

}
